@@ -184,7 +184,7 @@ AlgorithmsRegistry.add(
 )
 
 dt_regression_params = {
-    "criterion": ["mse", "friedman_mse", "mae"],
+    "criterion": ["mse", "friedman_mse"], # remove "mae" because it slows down a lot https://github.com/scikit-learn/scikit-learn/issues/9626
     "max_depth": [1, 2, 3, 4],
 }
 regression_required_preprocessing = ["missing_values_inputation", "convert_categorical"]
